static const char *pl_strings = "\"  -a               Cancel all jobs (cancel).\" = \"  -a               Anuluj wszystkie zadania (cancel).\";\n"
"\"  -c COPIES\" = \"  -c KOPIE\";\n"
"\"  -d PRINTER       Specify printer.\" = \"  -d DRUKARKA       Określ drukarkę.\";\n"
"\"  -j JOB-ID        Specify job ID (cancel).\" = \"  -j ID-ZADANIA         Określ identyfikator zadania (cancel).\";\n"
"\"  -m DRIVER-NAME   Specify driver (add/modify).\" = \"  -m NAZWA-STEROWNIKA   Określ sterownik (add/modify).\";\n"
"\"  -n COPIES        Specify number of copies (submit).\" = \"  -n KOPIE        Określ liczbę kopii (submit).\";\n"
"\"  -o %s=%s (default)\" = \"  -o %s=%s (default)\";\n"
"\"  -o NAME=VALUE    Specify option (add,modify,server,submit).\" = \"  -o NAZWA=WARTOŚĆ    Określ opcję (add,modify,server,submit).\";\n"
"\"  -o print-darkness=-100 to 100\" = \"  -o print-darkness=-100 do 100\";\n"
"\"  -o printer-darkness=0 to 100\" = \"  -o printer-darkness=0 do 100\";\n"
"\"  -o printer-geo-location='geo:LATITUDE,LONGITUDE'\" = \"  -o printer-geo-location='geo:SZEROKOŚĆ,DŁUGOŚĆ'\";\n"
"\"  -o printer-location='LOCATION'\" = \"  -o printer-location='LOKALIZACJA'\";\n"
"\"  -o printer-organization='ORGANIZATION'\" = \"  -o printer-organization='ORGANIZACJA'\";\n"
"\"  -o printer-organizational-unit='UNIT/SECTION'\" = \"  -o printer-organizational-unit='JEDNOSTKA/SEKCJA'\";\n"
"\"  -u URI           Specify ipp: or ipps: printer/server.\" = \"  -u URI           Określ ipp: lub ipps: drukarka/serwer.\";\n"
"\"  -v DEVICE-URI    Specify socket: or usb: device (add/modify).\" = \"  -v URI-URZĄDZENIA    Podaj gniazdo: lub usb: urządzenie (add/modify).\";\n"
"\"  add PRINTER      Add a printer.\" = \"  add DRUKARKA      Dodaj drukarkę.\";\n"
"\"  autoadd          Automatically add supported printers.\" = \"  autoadd          Automatyczne dodawanie obsługiwanych drukarek.\";\n"
"\"  cancel           Cancel one or more jobs.\" = \"  cancel           Anuluj jedno lub więcej zadań.\";\n"
"\"  default          Set the default printer.\" = \"  default          Ustaw domyślną drukarkę.\";\n"
"\"  delete           Delete a printer.\" = \"  delete           Usuń drukarkę.\";\n"
"\"  devices          List devices.\" = \"  devices          Wyświetl listę urządzeń.\";\n"
"\"  drivers          List drivers.\" = \"  drivers          Wyświetl listę sterowników.\";\n"
"\"  jobs             List jobs.\" = \"  jobs             Wyświetl listę zadań.\";\n"
"\"  modify           Modify a printer.\" = \"  modify           Zmodyfikuj drukarkę.\";\n"
"\"  options          List printer options.\" = \"  options          Wyświetl listę opcji drukarki.\";\n"
"\"  pause            Pause printing for a printer.\" = \"  pause            Wstrzymaj drukowanie drukarki.\";\n"
"\"  printers         List printers.\" = \"  printers        Wyświetl listę drukarek.\";\n"
"\"  resume           Resume printing for a printer.\" = \"  resume           Wznów drukowanie drukarki.\";\n"
"\"  server           Run a server.\" = \"  server           Uruchom serwer.\";\n"
"\"  shutdown         Shutdown a running server.\" = \"  shutdown         Wyłącz uruchomiony serwer.\";\n"
"\"  status           Show server/printer/job status.\" = \"  status           Pokaż stan serwera/drukarki/zadania.\";\n"
"\"  submit           Submit a file for printing.\" = \"  submit           Prześlij plik do druku.\";\n"
"\"%04d-%02d-%02d at %02d:%02d:%02d\" = \"%04d.%02d.%02d o %02d:%02d:%02d\";\n"
"\"%d days ago at %02d:%02d:%02d\" = \"%d dni temu o %02d:%02d:%02d\";\n"
"\"%d inches/sec\" = \"%d in/s\";\n"
"\"%d job\" = \"%d zadanie\";\n"
/* Media size in millimeters */
"\"%d x %dmm\" = \"%d x %d mm\";\n"
"\"%ddpi\" = \"%d dpi\";\n"
"\"%dx%ddpi\" = \"%d x %d dpi\";\n"
/* Media size in inches */
"\"%g x %g\\\"\" = \"%g x %g\\\"\";\n"
/* size (type+borderless) */
"\"%s (%s%s)\" = \"%s (%s%s)\";\n"
/* size (type+borderless) from source/tray */
"\"%s (%s%s) from %s\" = \"%s (%s%s) z %s\";\n"
/* Source/Tray Media */
"\"%s Media\" = \"%s Nośnik\";\n"
"\"%s: Bad 'server-port' value.\" = \"%s: Nieprawidłowa wartość 'server-port'.\";\n"
"\"%s: Bad job ID.\" = \"%s: Nieprawidłowy identyfikator zadania.\";\n"
"\"%s: Bad printer URI '%s'.\" = \"%s: Nieprawidłowy URI drukarki '%s'.\";\n"
"\"%s: Cannot specify more than one sub-command.\" = \"%s: Nie można określić więcej niż jednego polecenia podrzędnego.\";\n"
"\"%s: Empty print file received on the standard input.\" = \"%s: Odebrano pusty plik do wydruku na standardowym wejściu.\";\n"
"\"%s: Failed to create a system.\" = \"%s: Nie udało się utworzyć systemu.\";\n"
"\"%s: Missing '-d PRINTER'.\" = \"%s: Brak '-d DRUKARKA'.\";\n"
"\"%s: Missing '-m DRIVER-NAME'.\" = \"%s: Brak '-m NAZWA-STEROWNIKA'.\";\n"
"\"%s: Missing '-v DEVICE-URI'.\" = \"%s: Brak '-v URI-URZĄDZENIA'.\";\n"
"\"%s: Missing copy count after '-n'.\" = \"%s: Brak liczby kopii po '-n'.\";\n"
"\"%s: Missing device URI after '-v'.\" = \"%s: Brak URI urządzenia po '-v'.\";\n"
"\"%s: Missing driver name after '-m'.\" = \"%s: Brak nazwy sterownika po '-m'.\";\n"
"\"%s: Missing filename after '--'.\" = \"%s: Brak nazwy pliku po '--'.\";\n"
"\"%s: Missing hostname after '-h'.\" = \"%s: Brak nazwy hosta po '-h'.\";\n"
"\"%s: Missing job ID after '-j'.\" = \"%s: Brak identyfikatora zadania po '-j'.\";\n"
"\"%s: Missing option(s) after '-o'.\" = \"%s: Brak opcji po '-o'.\";\n"
"\"%s: Missing printer URI after '-u'.\" = \"%s: Brak URI drukarki po '-u'.\";\n"
"\"%s: Missing printer name after '-d'.\" = \"%s: Brak nazwy drukarki po '-d'.\";\n"
"\"%s: Missing space after '-o'.\" = \"%s: Brak spacji po '-o'.\";\n"
"\"%s: Missing title after '-t'.\" = \"%s: Brak tytułu po '-t'.\";\n"
"\"%s: No default printer available.\" = \"%s: Brak dostępnej drukarki domyślnej.\";\n"
"\"%s: No files to print.\" = \"%s: Brak plików do wydrukowania.\";\n"
"\"%s: Server is not running.\" = \"%s: Serwer nie jest uruchomiony.\";\n"
"\"%s: Sub-command '%s' does not accept files.\" = \"%s: Podpolecenie '%s' nie akceptuje plików.\";\n"
"\"%s: Sub-command 'autoadd' is not supported.\" = \"%s: Podpolecenie 'autoadd' nie jest obsługiwane.\";\n"
"\"%s: Too many files.\" = \"%s: Zbyt wiele plików.\";\n"
"\"%s: Unable to access '%s': %s\" = \"%s: Nie można uzyskać dostępu do '%s': %s\";\n"
"\"%s: Unable to add printer: %s\" = \"%s: Nie można dodać drukarki: %s\";\n"
"\"%s: Unable to cancel job: %s\" = \"%s: Nie można anulować zadania: %s\";\n"
"\"%s: Unable to connect to printer at '%s:%d': %s\" = \"%s: Nie można połączyć się z drukarką w '%s:%d': %s\";\n"
"\"%s: Unable to connect to server: %s\" = \"%s: Nie można połączyć się z serwerem: %s\";\n"
"\"%s: Unable to create temporary file: %s\" = \"%s: Nie można utworzyć pliku tymczasowego: %s\";\n"
"\"%s: Unable to delete printer: %s\" = \"%s: Nie można usunąć drukarki: %s\";\n"
"\"%s: Unable to get available devices: %s\" = \"%s: Nie można uzyskać dostępnych urządzeń: %s\";\n"
"\"%s: Unable to get information for '%s': %s\" = \"%s: Nie można uzyskać informacji o '%s': %s\";\n"
"\"%s: Unable to get information for printer: %s\" = \"%s: Nie można uzyskać informacji o drukarce: %s\";\n"
"\"%s: Unable to get printer options: %s\" = \"%s: Nie można uzyskać opcji drukarki: %s\";\n"
"\"%s: Unable to modify printer: %s\" = \"%s: Nie można zmodyfikować drukarki: %s\";\n"
"\"%s: Unable to pause printer: %s\" = \"%s: Nie można wstrzymać drukarki: %s\";\n"
"\"%s: Unable to print '%s': %s\" = \"%s: Nie można wydrukować '%s': %s\";\n"
"\"%s: Unable to resume printer: %s\" = \"%s: Nie można wznowić drukarki: %s\";\n"
"\"%s: Unable to set default printer: %s\" = \"%s: Nie można ustawić domyślnej drukarki: %s\";\n"
"\"%s: Unable to shutdown server: %s\" = \"%s: Nie można wyłączyć serwera: %s\";\n"
"\"%s: Unable to start server: %s\" = \"%s: Nie można uruchomić serwera: %s\";\n"
"\"%s: Unable to write to temporary file: %s\" = \"%s: Nie można zapisać do pliku tymczasowego: %s\";\n"
"\"%s: Unknown option '%s'.\" = \"%s: Nieznana opcja '%s'.\";\n"
"\"%s: Unknown option '-%c'.\" = \"%s: Nieznana opcja '-%c'.\";\n"
"\"%s: Unknown sub-command '%s'.\" = \"%s: Nieznane podpolecenie '%s'.\";\n"
"\"%s: Unsupported URI scheme '%s'.\" = \"%s: Nieobsługiwany schemat URI '%s'.\";\n"
"\"%s: Warning - user credentials are not supported in URIs.\" = \"%s: Ostrzeżenie — poświadczenia użytkownika nie są obsługiwane w URI.\";\n"
"\", Borderless\" = \", Bez obramowania\";\n"
"\"A printer with that name already exists.\" = \"Drukarka o tej nazwie już istnieje.\";\n"
"\"Aborted %s\" = \"Przerwano %s\";\n"
"\"Add Printer\" = \"Dodaj drukarkę\";\n"
"\"Admin Group\" = \"Grupa administratorów\";\n"
"\"Afghanistan\" = \"Afganistan\";\n"
"\"Albania\" = \"Albania\";\n"
"\"Algeria\" = \"Algieria\";\n"
"\"American Samoa\" = \"Samoa Amerykańskie\";\n"
"\"Andorra\" = \"Andora\";\n"
"\"Angola\" = \"Angola\";\n"
"\"Anguilla\" = \"Anguilla\";\n"
"\"Antarctica\" = \"Antarktyda\";\n"
"\"Antigua and Barbuda\" = \"Antigua i Barbuda\";\n"
"\"Argentina\" = \"Argentyna\";\n"
"\"Armenia\" = \"Armenia\";\n"
"\"Aruba\" = \"Aruba\";\n"
"\"Australia\" = \"Australia\";\n"
"\"Austria\" = \"Austria\";\n"
"\"Auto\" = \"Automatycznie\";\n"
"\"Auto-Detect Driver\" = \"Automatyczne wykrywanie sterownika\";\n"
"\"Azerbaijan\" = \"Azerbejdżan\";\n"
"\"Bad administration group.\" = \"Zła grupa administracyjna.\";\n"
"\"Bad port number.\" = \"Zły numer portu.\";\n"
"\"Bad print group.\" = \"Zła grupa drukowania.\";\n"
"\"Bad printer defaults.\" = \"Złe ustawienia domyślne drukarki.\";\n"
"\"Bahamas\" = \"Bahamy\";\n"
"\"Bahrain\" = \"Bahrajn\";\n"
"\"Bangladesh\" = \"Bangladesz\";\n"
"\"Barbados\" = \"Barbados\";\n"
"\"Belarus\" = \"Białoruś\";\n"
"\"Belgium\" = \"Belgia\";\n"
"\"Belize\" = \"Belize\";\n"
"\"Benin\" = \"Benin\";\n"
"\"Bermuda\" = \"Bermudy\";\n"
"\"Bhutan\" = \"Bhutan\";\n"
"\"Bolivia (Plurinational State of)\" = \"Boliwia (Wielonarodowe Państwo Boliwia)\";\n"
"\"Bonaire, Sint Eustatius and Saba\" = \"Bonaire, Sint Eustatius i Saba\";\n"
"\"Borderless\" = \"Bez obramowania\";\n"
"\"Bosnia and Herzegovina\" = \"Bośnia i Hercegowina\";\n"
"\"Botswana\" = \"Botswana\";\n"
"\"Bouvet Island\" = \"Wyspa Bouveta\";\n"
"\"Brazil\" = \"Brazylia\";\n"
"\"British Indian Ocean Territory\" = \"Brytyjskie Terytorium Oceanu Indyjskiego\";\n"
"\"Brunei Darussalam\" = \"Brunei Darussalam\";\n"
"\"Bulgaria\" = \"Bułgaria\";\n"
"\"Burkina Faso\" = \"Burkina Faso\";\n"
"\"Burundi\" = \"Burundi\";\n"
"\"Cabo Verde\" = \"Republika Zielonego Przylądka\";\n"
"\"Cambodia\" = \"Kambodża\";\n"
"\"Cameroon\" = \"Kamerun\";\n"
"\"Canada\" = \"Kanada\";\n"
"\"Cancel All Jobs\" = \"Anuluj wszystkie zadania\";\n"
"\"Cancel Job\" = \"Anuluj zadanie\";\n"
"\"Canceled %s\" = \"Anulowano %s\";\n"
"\"Canceling\" = \"Anulowanie\";\n"
"\"Cayman Islands\" = \"Kajmany\";\n"
"\"Central African Republic\" = \"Republika Środkowoafrykańska\";\n"
"\"Certificate created.\" = \"Certyfikat utworzony.\";\n"
"\"Certificate installed.\" = \"Certyfikat zainstalowany.\";\n"
"\"Certificate request created.\" = \"Żądanie certyfikatu utworzone.\";\n"
"\"Chad\" = \"Czad\";\n"
"\"Change Access Password\" = \"Zmień hasło dostępu\";\n"
"\"Change Log Level\" = \"Zmień poziom dziennika\";\n"
"\"Change Network Settings\" = \"Zmień ustawienia sieciowe\";\n"
"\"Change Wi-Fi Network\" = \"Zmień sieć Wi-Fi\";\n"
"\"Changes Saved.\" = \"Zmiany zapisane.\";\n"
"\"Changes saved.\" = \"Zmiany zapisane.\";\n"
"\"Chile\" = \"Chile\";\n"
"\"China\" = \"Chiny\";\n"
"\"Christmas Island\" = \"Wyspa Bożego Narodzenia\";\n"
"\"City/Locality\" = \"Miasto/Miejscowość\";\n"
"\"Cocos (Keeling) Islands\" = \"Wyspy Kokosowe (Keelinga)\";\n"
"\"Colombia\" = \"Kolumbia\";\n"
"\"Comoros\" = \"Komory\";\n"
"\"Completed %s\" = \"Ukończono %s\";\n"
"\"Configuration\" = \"Konfiguracja\";\n"
"\"Configure Media\" = \"Konfigurowanie nośników\";\n"
"\"Confirm Cancel All\" = \"Potwierdź anulowanie wszystkiego\";\n"
"\"Confirm Delete Printer\" = \"Potwierdź usunięcie drukarki\";\n"
"\"Congo\" = \"Kongo\";\n"
"\"Congo, Democratic Republic of the\" = \"Kongo, Republika Demokratyczna\";\n"
"\"Contact\" = \"Kontakt\";\n"
"\"Cook Islands\" = \"Wyspy Cooka\";\n"
"\"Costa Rica\" = \"Kostaryka\";\n"
"\"Create Certificate Signing Request\" = \"Utwórz żądanie podpisania certyfikatu\";\n"
"\"Create New Certificate\" = \"Utwórz nowy certyfikat\";\n"
"\"Create New TLS Certificate\" = \"Utwórz nowy certyfikat TLS\";\n"
"\"Create TLS Certificate Request\" = \"Utwórz żądanie certyfikatu TLS\";\n"
"\"Croatia\" = \"Chorwacja\";\n"
"\"Cuba\" = \"Kuba\";\n"
"\"Curaçao\" = \"Curaçao\";\n"
"\"Current Password\" = \"Aktualne hasło\";\n"
"\"Custom Size\" = \"Rozmiar niestandardowy\";\n"
"\"Cyprus\" = \"Cypr\";\n"
"\"Czechia\" = \"Czechy\";\n"
"\"Côte d'Ivoire\" = \"Wybrzeże Kości Słoniowej\";\n"
"\"DHCP\" = \"DHCP\";\n"
"\"DHCP w/Manual Address\" = \"DHCP z adresem ręcznym\";\n"
"\"DNS-SD Service Name\" = \"Nazwa usługi DNS-SD\";\n"
"\"Debugging\" = \"Debugowanie\";\n"
"\"Default printer set.\" = \"Domyślny zestaw drukarki.\";\n"
"\"Delete\" = \"Usuń\";\n"
"\"Delete Printer\" = \"Usuń drukarkę\";\n"
"\"Denmark\" = \"Dania\";\n"
"\"Djibouti\" = \"Dżibuti\";\n"
"\"Domain Name\" = \"Nazwa domeny\";\n"
"\"Dominica\" = \"Dominika\";\n"
"\"Dominican Republic\" = \"Republika Dominikany\";\n"
"\"Download Certificate Request File\" = \"Pobierz plik żądania certyfikatu\";\n"
"\"Ecuador\" = \"Ekwador\";\n"
"\"Egypt\" = \"Egipt\";\n"
"\"El Salvador\" = \"Salwador\";\n"
"\"Equatorial Guinea\" = \"Gwinea Równikowa\";\n"
"\"Eritrea\" = \"Erytrea\";\n"
"\"Errors\" = \"Błędy\";\n"
"\"Estonia\" = \"Estonia\";\n"
"\"Eswatini\" = \"Eswatini\";\n"
"\"Ethiopia\" = \"Etiopia\";\n"
"\"Falkland Islands (Malvinas)\" = \"Falklandy (Malwiny)\";\n"
"\"Faroe Islands\" = \"Wyspy Owcze\";\n"
"\"Fatal Errors/Conditions\" = \"Krytyczne błędy/warunki\";\n"
"\"Fiji\" = \"Fidżi\";\n"
"\"Finland\" = \"Finlandia\";\n"
"\"France\" = \"Francja\";\n"
"\"French Guiana\" = \"Gujana Francuska\";\n"
"\"French Polynesia\" = \"Polinezja Francuska\";\n"
"\"French Southern Territories\" = \"Francuskie Terytoria Południowe\";\n"
"\"Gabon\" = \"Gabon\";\n"
"\"Gambia\" = \"Gambia\";\n"
"\"Georgia\" = \"Gruzja\";\n"
"\"Germany\" = \"Niemcy\";\n"
"\"Ghana\" = \"Ghana\";\n"
"\"Gibraltar\" = \"Gibraltar\";\n"
"\"Greece\" = \"Grecja\";\n"
"\"Greenland\" = \"Grenlandia\";\n"
"\"Grenada\" = \"Grenada\";\n"
"\"Group changes saved.\" = \"Zmiany w grupie zapisane.\";\n"
"\"Guadeloupe\" = \"Gwadelupa\";\n"
"\"Guam\" = \"Guam\";\n"
"\"Guatemala\" = \"Gwatemala\";\n"
"\"Guernsey\" = \"Guernsey\";\n"
"\"Guinea\" = \"Gwinea\";\n"
"\"Guinea-Bissau\" = \"Gwinea Bissau\";\n"
"\"Guyana\" = \"Gujana\";\n"
"\"Haiti\" = \"Haiti\";\n"
"\"Heard Island and McDonald Islands\" = \"Wyspy Heard i McDonalda\";\n"
"\"Hidden SSID\" = \"Ukryty SSID\";\n"
"\"Hold Job\" = \"Wstrzymaj zadanie\";\n"
"\"Hold New Jobs\" = \"Wstrzymuj nowe zadania\";\n"
"\"Holding new jobs.\" = \"Wstrzymywanie nowych zadań.\";\n"
"\"Holy See\" = \"Stolica Apostolska\";\n"
"\"Honduras\" = \"Honduras\";\n"
"\"Hong Kong\" = \"Hongkong\";\n"
"\"Hostname\" = \"Nazwa hosta\";\n"
"\"Human-Readable Location\" = \"Lokalizacja czytelna dla człowieka\";\n"
"\"Hungary\" = \"Węgry\";\n"
"\"IPv4 Address\" = \"Adres IPv4\";\n"
"\"IPv4 Configuration\" = \"Konfiguracja IPv4\";\n"
"\"IPv4 Gateway\" = \"Brama IPv4\";\n"
"\"IPv4 Netmask\" = \"Maska sieci IPv4\";\n"
"\"IPv6 Address\" = \"Adres IPv6\";\n"
"\"IPv6 Configuration\" = \"Konfiguracja IPv6\";\n"
"\"IPv6 Link-Local\" = \"Łącze lokalne IPv6\";\n"
"\"IPv6 Prefix Length\" = \"Długość prefiksu IPv6\";\n"
"\"Iceland\" = \"Islandia\";\n"
"\"Identify Printer\" = \"Zidentyfikuj drukarkę\";\n"
"\"India\" = \"Indie\";\n"
"\"Indonesia\" = \"Indonezja\";\n"
"\"Informational\" = \"Informacyjny\";\n"
"\"Install TLS Certificate\" = \"Zainstaluj certyfikat TLS\";\n"
"\"Invalid IPv4 address.\" = \"Nieprawidłowy adres IPv4.\";\n"
"\"Invalid IPv4 netmask.\" = \"Nieprawidłowa maska sieci IPv4.\";\n"
"\"Invalid IPv6 address.\" = \"Nieprawidłowy adres IPv6.\";\n"
"\"Invalid IPv6 prefix length.\" = \"Nieprawidłowa długość prefiksu IPv6.\";\n"
"\"Invalid Job ID.\" = \"Nieprawidłowy identyfikator zadania.\";\n"
"\"Invalid certificate or private key.\" = \"Nieprawidłowy certyfikat lub klucz prywatny.\";\n"
"\"Invalid form data.\" = \"Nieprawidłowe dane formularza.\";\n"
"\"Invalid form submission.\" = \"Nieprawidłowe wysłanie formularza.\";\n"
"\"Invalid job ID.\" = \"Nieprawidłowy identyfikator zadania.\";\n"
"\"Invalid network configuration.\" = \"Nieprawidłowa konfiguracja sieci.\";\n"
"\"Iran (Islamic Republic of)\" = \"Iran (Islamska Republika Iranu)\";\n"
"\"Iraq\" = \"Irak\";\n"
"\"Ireland\" = \"Irlandia\";\n"
"\"Isle of Man\" = \"Wyspa Man\";\n"
"\"Israel\" = \"Izrael\";\n"
"\"Italy\" = \"Włochy\";\n"
"\"Jamaica\" = \"Jamajka\";\n"
"\"Japan\" = \"Japonia\";\n"
"\"Jersey\" = \"Jersey\";\n"
"\"Job #\" = \"Zadanie #\";\n"
"\"Job canceled.\" = \"Zadanie anulowane.\";\n"
"\"Job held.\" = \"Zadanie wstrzymane.\";\n"
"\"Job released.\" = \"Zadanie wznowione.\";\n"
"\"Jobs\" = \"Zadania\";\n"
"\"Joining Wi-Fi Network\" = \"Dołączanie do sieci Wi-Fi\";\n"
"\"Jordan\" = \"Jordania\";\n"
"\"Kazakhstan\" = \"Kazachstan\";\n"
"\"Kenya\" = \"Kenia\";\n"
"\"Kiribati\" = \"Kiribati\";\n"
"\"Korea (Democratic People's Republic of)\" = \"Korea (Koreańska Republika Ludowo-Demokratyczna)\";\n"
"\"Korea, Republic of\" = \"Korea (Republika Korei)\";\n"
"\"Kuwait\" = \"Kuwejt\";\n"
"\"Kyrgyzstan\" = \"Kirgistan\";\n"
"\"Landscape\" = \"Poziomo\";\n"
"\"Lao People's Democratic Republic\" = \"Laotańska Republika Ludowo-Demokratyczna\";\n"
"\"Latvia\" = \"Łotwa\";\n"
"\"Lebanon\" = \"Liban\";\n"
"\"Lesotho\" = \"Lesotho\";\n"
"\"Level\" = \"Poziom\";\n"
"\"Liberia\" = \"Liberia\";\n"
"\"Libya\" = \"Libia\";\n"
"\"Liechtenstein\" = \"Liechtenstein\";\n"
"\"Lithuania\" = \"Litwa\";\n"
"\"Location\" = \"Lokalizacja\";\n"
"\"Log Level\" = \"Poziom dziennika\";\n"
"\"Logging\" = \"Rejestrowanie\";\n"
"\"Logs\" = \"Dzienniki\";\n"
"\"Luxembourg\" = \"Luksemburg\";\n"
"\"Macao\" = \"Makao\";\n"
"\"Madagascar\" = \"Madagaskar\";\n"
"\"Malawi\" = \"Malawi\";\n"
"\"Malaysia\" = \"Malezja\";\n"
"\"Maldives\" = \"Malediwy\";\n"
"\"Mali\" = \"Mali\";\n"
"\"Malta\" = \"Malta\";\n"
"\"Manual Configuration\" = \"Konfiguracja ręczna\";\n"
"\"Marshall Islands\" = \"Wyspy Marshalla\";\n"
"\"Martinique\" = \"Martynika\";\n"
"\"Mauritania\" = \"Mauretania\";\n"
"\"Mauritius\" = \"Mauritius\";\n"
"\"Mayotte\" = \"Majotta\";\n"
"\"Media\" = \"Nośniki\";\n"
"\"Mexico\" = \"Meksyk\";\n"
"\"Micronesia (Federated States of)\" = \"Mikronezja (Sfederowane Stany Mikronezji)\";\n"
"\"Missing action.\" = \"Brak działania.\";\n"
"\"Missing job ID.\" = \"Brak identyfikatora zadania.\";\n"
"\"Missing network name.\" = \"Brak nazwy sieci.\";\n"
"\"Missing private key.\" = \"Brak klucza prywatnego.\";\n"
"\"Moldova, Republic of\" = \"Mołdawia, Republika Mołdawii\";\n"
"\"Monaco\" = \"Monako\";\n"
"\"Mongolia\" = \"Mongolia\";\n"
"\"Montenegro\" = \"Czarnogóra\";\n"
"\"Montserrat\" = \"Montserrat\";\n"
"\"Morocco\" = \"Maroko\";\n"
"\"Mozambique\" = \"Mozambik\";\n"
"\"Myanmar\" = \"Myanmar\";\n"
"\"Name\" = \"Nazwa\";\n"
"\"Namibia\" = \"Namibia\";\n"
"\"Nauru\" = \"Nauru\";\n"
"\"Nepal\" = \"Nepal\";\n"
"\"Netherlands\" = \"Holandia\";\n"
"\"Network\" = \"Sieć\";\n"
"\"Network Printer\" = \"Drukarka sieciowa\";\n"
"\"Networking\" = \"Sieciowość\";\n"
"\"New Caledonia\" = \"Nowa Kaledonia\";\n"
"\"New Zealand\" = \"Nowa Zelandia\";\n"
"\"Nicaragua\" = \"Nikaragua\";\n"
"\"Niger\" = \"Niger\";\n"
"\"Nigeria\" = \"Nigeria\";\n"
"\"Niue\" = \"Niue\";\n"
"\"No default printer set.\" = \"Nie ustawiono drukarki domyślnej.\";\n"
"\"No jobs in history.\" = \"Nie ma zadań w historii.\";\n"
"\"Norfolk Island\" = \"Wyspa Norfolk\";\n"
"\"North Macedonia\" = \"Macedonia Północna\";\n"
"\"Northern Mariana Islands\" = \"Mariany Północne\";\n"
"\"Norway\" = \"Norwegia\";\n"
"\"Not set\" = \"Nie ustawiono\";\n"
"\"Off\" = \"Wyłączony\";\n"
"\"Offset\" = \"Przesunięcie\";\n"
"\"Oman\" = \"Oman\";\n"
"\"Options:\" = \"Opcje:\";\n"
"\"Organization\" = \"Organizacja\";\n"
"\"Organization Name\" = \"Nazwa organizacji\";\n"
"\"Other Settings\" = \"Inne ustawienia\";\n"
"\"Pakistan\" = \"Pakistan\";\n"
"\"Palau\" = \"Palau\";\n"
"\"Palestine, State of\" = \"Palestyna, Państwo Palestyna\";\n"
"\"Panama\" = \"Panama\";\n"
"\"Papua New Guinea\" = \"Papua Nowa Gwinea\";\n"
"\"Paraguay\" = \"Paragwaj\";\n"
"\"Password\" = \"Hasło\";\n"
"\"Password changed.\" = \"Hasło zostało zmienione.\";\n"
"\"Password must be at least eight characters long and contain at least one uppercase letter, one lowercase letter, and one digit.\" = \"Hasło musi mieć co najmniej osiem znaków i zawierać co najmniej jedną wielką literę, jedną małą literę i jedną cyfrę.\";\n"
"\"Passwords do not match.\" = \"Hasła nie pasują do siebie.\";\n"
"\"Pause Printing\" = \"Wstrzymaj drukowanie\";\n"
"\"Peru\" = \"Peru\";\n"
"\"Philippines\" = \"Filipiny\";\n"
"\"Pitcairn\" = \"Pitcairn\";\n"
"\"Please enter a hostname or IP address for the printer.\" = \"Wprowadź nazwę hosta lub adres IP drukarki.\";\n"
"\"Please enter a printer name.\" = \"Wprowadź nazwę drukarki.\";\n"
"\"Please select a device.\" = \"Wybierz urządzenie.\";\n"
"\"Please select a driver.\" = \"Wybierz sterownik.\";\n"
"\"Please select a valid log level.\" = \"Wybierz odpowiedni poziom rejestrowania.\";\n"
"\"Poland\" = \"Polska\";\n"
"\"Portrait\" = \"Pionowo\";\n"
"\"Portugal\" = \"Portugalia\";\n"
"\"Primary DNS\" = \"Podstawowy DNS\";\n"
"\"Print Group\" = \"Grupa drukowania\";\n"
"\"Print Test Page\" = \"Wydrukuj stronę testową\";\n"
"\"Print job options:\" = \"Opcje zadania drukowania:\";\n"
"\"Printer identified.\" = \"Drukarka zidentyfikowana.\";\n"
"\"Printer is currently active.\" = \"Drukarka jest obecnie aktywna.\";\n"
"\"Printer names must start with a letter or underscore and cannot contain special characters.\" = \"Nazwy drukarek muszą zaczynać się od litery lub podkreślenia i nie mogą zawierać znaków specjalnych.\";\n"
"\"Printer options:\" = \"Opcje drukarki:\";\n"
"\"Printer paused.\" = \"Drukarka wstrzymana.\";\n"
"\"Printer pausing.\" = \"Wstrzymanie drukarki.\";\n"
"\"Printer resuming.\" = \"Wznawianie drukarki.\";\n"
"\"Printers\" = \"Drukarki\";\n"
"\"Printing Defaults\" = \"Ustawienia domyślne drukowania\";\n"
"\"Puerto Rico\" = \"Portoryko\";\n"
"\"Qatar\" = \"Katar\";\n"
"\"Queued %s\" = \"W kolejce %s\";\n"
"\"Release Held New Jobs\" = \"Wznów wstrzymane nowe zadania\";\n"
"\"Release Job\" = \"Wznów zadanie\";\n"
"\"Released held new jobs.\" = \"Wznowiono wstrzymane nowe zadania.\";\n"
"\"Reprint Job\" = \"Zadanie przedruku\";\n"
"\"Reprinted job.\" = \"Przedrukowane zadanie.\";\n"
"\"Resume Printing\" = \"Wznów drukowanie\";\n"
"\"Reverse Landscape\" = \"Poziomy (obrócony)\";\n"
"\"Reverse Portrait\" = \"Pionowy (obrócony)\";\n"
"\"Romania\" = \"Rumunia\";\n"
/* Running, STATE since DATE REASONS */
"\"Running, %s since %s%s.\" = \"Uruchomiony, %s od %s%s.\";\n"
"\"Russian Federation\" = \"Federacja Rosyjska\";\n"
"\"Rwanda\" = \"Rwanda\";\n"
"\"Réunion\" = \"Réunion\";\n"
"\"Saint Barthélemy\" = \"Saint-Barthélemy\";\n"
"\"Saint Helena, Ascension and Tristan da Cunha\" = \"Święta Helena, Wniebowstąpienie i Tristan da Cunha\";\n"
"\"Saint Kitts and Nevis\" = \"Saint Kitts i Nevis\";\n"
"\"Saint Lucia\" = \"Saint Lucia\";\n"
"\"Saint Martin (French part)\" = \"Saint Martin (część francuska)\";\n"
"\"Saint Pierre and Miquelon\" = \"Saint-Pierre i Miquelon\";\n"
"\"Saint Vincent and the Grenadines\" = \"Saint Vincent i Grenadyny\";\n"
"\"Samoa\" = \"Samoa\";\n"
"\"San Marino\" = \"San Marino\";\n"
"\"Sao Tome and Principe\" = \"Wyspy Świętego Tomasza i Książęca\";\n"
"\"Saudi Arabia\" = \"Arabia Saudyjska\";\n"
"\"Save Changes\" = \"Zapisz zmiany\";\n"
"\"Secondary DNS\" = \"Pomocniczy DNS\";\n"
"\"Security\" = \"Bezpieczeństwo\";\n"
"\"Select Driver\" = \"Wybierz sterownik\";\n"
"\"Senegal\" = \"Senegal\";\n"
"\"Serbia\" = \"Serbia\";\n"
"\"Server is not running.\" = \"Serwer nie jest uruchomiony.\";\n"
"\"Set Access Password\" = \"Ustaw hasło dostępu\";\n"
"\"Set as Default\" = \"Ustaw jako domyślne\";\n"
"\"Seychelles\" = \"Seszele\";\n"
"\"Sierra Leone\" = \"Sierra Leone\";\n"
"\"Singapore\" = \"Singapur\";\n"
"\"Sint Maarten (Dutch part)\" = \"Sint Maarten (część holenderska)\";\n"
"\"Slovakia\" = \"Słowacja\";\n"
"\"Slovenia\" = \"Słowenia\";\n"
"\"Solomon Islands\" = \"Wyspy Salomona\";\n"
"\"Somalia\" = \"Somalia\";\n"
"\"South Africa\" = \"Republika Południowej Afryki\";\n"
"\"South Georgia and the South Sandwich Islands\" = \"Georgia Południowa i Sandwich Południowy\";\n"
"\"South Sudan\" = \"Sudan Południowy\";\n"
"\"Spain\" = \"Hiszpania\";\n"
"\"Sri Lanka\" = \"Sri Lanka\";\n"
"\"Started %s\" = \"Rozpoczęto %s\";\n"
"\"Status\" = \"Status\";\n"
"\"Sub-commands:\" = \"Podkomendy:\";\n"
"\"Sudan\" = \"Sudan\";\n"
"\"Supplies\" = \"Materiały eksploatacyjne\";\n"
"\"Suriname\" = \"Surinam\";\n"
"\"Svalbard and Jan Mayen\" = \"Svalbard i Jan Mayen\";\n"
"\"Sweden\" = \"Szwecja\";\n"
"\"Switzerland\" = \"Szwajcaria\";\n"
"\"Syrian Arab Republic\" = \"Syryjska Republika Arabska\";\n"
"\"Taiwan, Province of China\" = \"Tajwan (prowincja Republiki Chińskiej)\";\n"
"\"Tajikistan\" = \"Tadżykistan\";\n"
"\"Tanzania, United Republic of\" = \"Tanzania, Zjednoczona Republika Tanzanii\";\n"
"\"Test page printed.\" = \"Strona testowa wydrukowana.\";\n"
"\"Thailand\" = \"Tajlandia\";\n"
"\"This form creates a certificate signing request ('CSR') that you can send to a Certificate Authority ('CA') to obtain a trusted TLS certificate. The private key is saved separately for use with the certificate you get from the CA.\" = \"Ten formularz tworzy żądanie podpisania certyfikatu („CSR”), które można wysłać do urzędu certyfikacji („CA”) w celu uzyskania zaufanego certyfikatu TLS. Klucz prywatny jest zapisywany oddzielnie do użytku z certyfikatem otrzymanym od urzędu certyfikacji.\";\n"
"\"This form creates a new 'self-signed' TLS certificate for secure printing. Self-signed certificates are not automatically trusted by web browsers.\" = \"Ten formularz tworzy nowy „samopodpisany” certyfikat TLS do bezpiecznego drukowania. Certyfikaty z podpisem własnym nie są automatycznie uznawane za zaufane przez przeglądarki internetowe.\";\n"
"\"This form will install a trusted TLS certificate you have obtained from a Certificate Authority ('CA'). Once installed, it will be used immediately.\" = \"Ten formularz zainstaluje zaufany certyfikat TLS uzyskany od urzędu certyfikacji („CA”). Po zainstalowaniu będzie natychmiast używany.\";\n"
"\"Timor-Leste\" = \"Timor Wschodni\";\n"
"\"Togo\" = \"Togo\";\n"
"\"Tokelau\" = \"Tokelau\";\n"
"\"Tonga\" = \"Tonga\";\n"
"\"Trinidad and Tobago\" = \"Trynidad i Tobago\";\n"
"\"Tunisia\" = \"Tunezja\";\n"
"\"Turkey\" = \"Turcja\";\n"
"\"Turkmenistan\" = \"Turkmenistan\";\n"
"\"Turks and Caicos Islands\" = \"Wyspy Turks i Caicos\";\n"
"\"Tuvalu\" = \"Tuvalu\";\n"
"\"Uganda\" = \"Uganda\";\n"
"\"Ukraine\" = \"Ukraina\";\n"
"\"Unable to access test print file.\" = \"Nie można uzyskać dostępu do pliku wydruku testowego.\";\n"
"\"Unable to copy print job.\" = \"Nie można skopiować zadania drukowania.\";\n"
"\"Unable to create certificate request.\" = \"Nie można utworzyć żądania certyfikatu.\";\n"
"\"Unable to create certificate.\" = \"Nie można utworzyć certyfikatu.\";\n"
"\"Unable to create test print job.\" = \"Nie można utworzyć testowego zadania drukowania.\";\n"
"\"Unable to identify printer.\" = \"Nie można zidentyfikować drukarki.\";\n"
"\"Unable to lookup address.\" = \"Nie można wyszukać adresu.\";\n"
"\"Unable to use that driver.\" = \"Nie można użyć tego sterownika.\";\n"
"\"United Arab Emirates\" = \"Zjednoczone Emiraty Arabskie\";\n"
"\"United Kingdom\" = \"Zjednoczone Królestwo\";\n"
"\"United Kingdom of Great Britain and Northern Ireland\" = \"Zjednoczone Królestwo Wielkiej Brytanii i Irlandii Północnej\";\n"
"\"United States Minor Outlying Islands\" = \"Dalekie Wyspy Mniejsze Stanów Zjednoczonych\";\n"
"\"United States of America\" = \"Stany Zjednoczone Ameryki\";\n"
"\"Unknown\" = \"Nieznany\";\n"
"\"Unknown action.\" = \"Nieznana czynność.\";\n"
"\"Unknown form action.\" = \"Nieznana czynność formularza.\";\n"
"\"Unknown form request.\" = \"Nieznane żądanie formularza.\";\n"
"\"Updating Network Configuration\" = \"Aktualizowanie konfiguracji sieci\";\n"
"\"Uruguay\" = \"Urugwaj\";\n"
"\"Usage: %s SUB-COMMAND [OPTIONS] [FILENAME]\\n\" = \"Użycie: %s SUB-COMMAND [OPCJE] [NAZWA PLIKU]\\n\";\n"
"\"Use My Position\" = \"Użyj mojej pozycji\";\n"
"\"Users\" = \"Użytkownicy\";\n"
"\"Uzbekistan\" = \"Uzbekistan\";\n"
"\"Vanuatu\" = \"Vanuatu\";\n"
"\"Venezuela (Bolivarian Republic of)\" = \"Wenezuela (Boliwariańska Republika Wenezueli)\";\n"
"\"Version %s\" = \"Wersja %\";\n"
"\"Viet Nam\" = \"Wietnam\";\n"
"\"View Logs\" = \"Wyświetl dzienniki\";\n"
"\"Virgin Islands (British)\" = \"Wyspy Dziewicze (brytyjskie)\";\n"
"\"Virgin Islands (U.S.)\" = \"Wyspy Dziewicze (amerykańskie)\";\n"
"\"Wallis and Futuna\" = \"Wallis i Futuna\";\n"
"\"Warning\" = \"Ostrzeżenie\";\n"
"\"Western Sahara\" = \"Sahara Zachodnia\";\n"
"\"Wi-Fi Configuration\" = \"Konfiguracja Wi-Fi\";\n"
"\"Wi-Fi Network\" = \"Sieć Wi-Fi\";\n"
"\"Width\" = \"Szerokość\";\n"
"\"Wrong old password.\" = \"Nieprawidłowe stare hasło.\";\n"
"\"Yemen\" = \"Jemen\";\n"
"\"Zambia\" = \"Zambia\";\n"
"\"Zimbabwe\" = \"Zimbabwe\";\n"
"\"at %02d:%02d:%02d\" = \"o %02d:%02d:%02d\";\n"
/* IPP attribute, keyword, and enum (integer) localizations */
"\"copies\" = \"Liczba kopii\";\n"
"\"default printer\" = \"drukarka domyślna\";\n"
"\"finishings\" = \"Wykończenie\";\n"
"\"finishings.10\" = \"Składanie\";\n"
"\"finishings.100\" = \"Składanie Z\";\n"
"\"finishings.101\" = \"Inżynierskie składanie Z\";\n"
"\"finishings.11\" = \"Cięcie\";\n"
"\"finishings.12\" = \"Bela\";\n"
"\"finishings.13\" = \"Kreator broszur\";\n"
"\"finishings.15\" = \"Płaszcz\";\n"
"\"finishings.16\" = \"Laminat\";\n"
"\"finishings.20\" = \"Zszywka na górze po lewej\";\n"
"\"finishings.21\" = \"Zszywka na dole po lewej\";\n"
"\"finishings.22\" = \"Zszywka na górze po prawej\";\n"
"\"finishings.23\" = \"Zszywka na dole po prawej\";\n"
"\"finishings.24\" = \"Lewy ścieg brzegowy\";\n"
"\"finishings.25\" = \"Górny ścieg brzegowy\";\n"
"\"finishings.26\" = \"Prawy ścieg brzegowy\";\n"
"\"finishings.27\" = \"Dolny ścieg brzegowy\";\n"
"\"finishings.28\" = \"2 zszywki po lewej\";\n"
"\"finishings.29\" = \"2 zszywki na górze\";\n"
"\"finishings.3\" = \"Brak\";\n"
"\"finishings.30\" = \"2 zszywki po prawej\";\n"
"\"finishings.31\" = \"2 zszywki na dole\";\n"
"\"finishings.32\" = \"3 zszywki po lewej\";\n"
"\"finishings.33\" = \"3 zszywki na górze\";\n"
"\"finishings.34\" = \"3 zszywki po prawej\";\n"
"\"finishings.35\" = \"3 zszywki na dole\";\n"
"\"finishings.4\" = \"Zszywka\";\n"
"\"finishings.5\" = \"Dziurkacz\";\n"
"\"finishings.50\" = \"Wiązanie po lewej\";\n"
"\"finishings.51\" = \"Wiązanie na górze\";\n"
"\"finishings.52\" = \"Wiązanie po prawej\";\n"
"\"finishings.53\" = \"Wiązanie na dole\";\n"
"\"finishings.6\" = \"Okładka\";\n"
"\"finishings.60\" = \"Cięcie po każdej stronie\";\n"
"\"finishings.61\" = \"Cięcie po każdym dokumencie\";\n"
"\"finishings.62\" = \"Cięcie po każdym zestawie\";\n"
"\"finishings.63\" = \"Cięcie po zadaniu\";\n"
"\"finishings.7\" = \"Wiązanie\";\n"
"\"finishings.70\" = \"Dziurkacz na górze po lewej\";\n"
"\"finishings.71\" = \"Dziurkacz na dole po lewej\";\n"
"\"finishings.72\" = \"Dziurkacz na górze po prawej\";\n"
"\"finishings.73\" = \"Dziurkacz na dole po prawej\";\n"
"\"finishings.74\" = \"2-otworowy dziurkacz po lewej\";\n"
"\"finishings.75\" = \"2-otworowy dziurkacz na górze\";\n"
"\"finishings.76\" = \"2-otworowy dziurkacz po prawej\";\n"
"\"finishings.77\" = \"2-otworowy dziurkacz na dole\";\n"
"\"finishings.78\" = \"3-otworowy dziurkacz po lewej\";\n"
"\"finishings.79\" = \"3-otworowy dziurkacz na górze\";\n"
"\"finishings.8\" = \"Ścieg siodłowy\";\n"
"\"finishings.80\" = \"3-otworowy dziurkacz po prawej\";\n"
"\"finishings.81\" = \"3-otworowy dziurkacz na dole\";\n"
"\"finishings.82\" = \"4-otworowy dziurkacz po lewej\";\n"
"\"finishings.83\" = \"4-otworowy dziurkacz na górze\";\n"
"\"finishings.84\" = \"4-otworowy dziurkacz po prawej\";\n"
"\"finishings.85\" = \"4-otworowy dziurkacz na dole\";\n"
"\"finishings.86\" = \"Wielootworowy dziurkacz po lewej\";\n"
"\"finishings.87\" = \"Wielootworowy dziurkacz na górze\";\n"
"\"finishings.88\" = \"Wielootworowy dziurkacz po prawej\";\n"
"\"finishings.89\" = \"Wielootworowy dziurkacz na dole\";\n"
"\"finishings.9\" = \"Ścieg brzegowy\";\n"
"\"finishings.90\" = \"Składanie akordeonowe\";\n"
"\"finishings.91\" = \"Składanie podwójnej bramy\";\n"
"\"finishings.92\" = \"Składanie bramy\";\n"
"\"finishings.93\" = \"Składanie połowiczne\";\n"
"\"finishings.94\" = \"Składanie połowiczne Z\";\n"
"\"finishings.95\" = \"Składanie bramy lewej\";\n"
"\"finishings.96\" = \"Składanie listu\";\n"
"\"finishings.97\" = \"Składanie równoległe\";\n"
"\"finishings.98\" = \"Składanie plakatu\";\n"
"\"finishings.99\" = \"Składanie bramy prawej\";\n"
"\"holding new jobs\" = \"wstrzymywanie nowych zadań\";\n"
"\"job-state-reasons.aborted-by-system\" = \"Zatrzymanie.\";\n"
"\"job-state-reasons.compression-error\" = \"Błąd dekompresji.\";\n"
"\"job-state-reasons.document-format-error\" = \"Błąd formatu dokumentu.\";\n"
"\"job-state-reasons.document-password-error\" = \"Błąd hasła dokumentu.\";\n"
"\"job-state-reasons.document-permission-error\" = \"Błąd uprawnień do dokumentu.\";\n"
"\"job-state-reasons.document-unprintable-error\" = \"Błąd uniemożliwiający drukowanie dokumentu.\";\n"
"\"job-state-reasons.errors-detected\" = \"Wykryto błędy.\";\n"
"\"job-state-reasons.job-canceled-at-device\" = \"Anulowano w drukarce.\";\n"
"\"job-state-reasons.job-canceled-by-user\" = \"Anulowano przez użytkownika.\";\n"
"\"job-state-reasons.job-completed-successfully\" = \"Wydrukowano.\";\n"
"\"job-state-reasons.job-completed-with-errors\" = \"Wydrukowano z błędami.\";\n"
"\"job-state-reasons.job-completed-with-warnings\" = \"Wydrukowano z ostrzeżeniami.\";\n"
"\"job-state-reasons.job-data-insufficient\" = \"Niewystarczające dane.\";\n"
"\"job-state-reasons.job-fetchable\" = \"Do pobrania.\";\n"
"\"job-state-reasons.job-incoming\" = \"Przychodzące.\";\n"
"\"job-state-reasons.job-printing\" = \"Drukowanie.\";\n"
"\"job-state-reasons.job-queued\" = \"Przygotowanie do drukowania.\";\n"
"\"job-state-reasons.job-spooling\" = \"Buforowanie.\";\n"
"\"job-state-reasons.none\" = \"W toku.\";\n"
"\"job-state-reasons.printer-stopped\" = \"Drukarka offline.\";\n"
"\"job-state-reasons.printer-stopped-partly\" = \"Drukarka częściowo zatrzymana.\";\n"
"\"job-state-reasons.processing-to-stop-point\" = \"Zatrzymanie.\";\n"
"\"job-state-reasons.queued-in-device\" = \"Gotowe.\";\n"
"\"job-state-reasons.warnings-detected\" = \"Wykryto ostrzeżenia.\";\n"
"\"job-state.3\" = \"W toku\";\n"
"\"job-state.4\" = \"Wstrzymane\";\n"
"\"job-state.5\" = \"Przetwarzanie\";\n"
"\"job-state.6\" = \"Zatrzymane\";\n"
"\"job-state.7\" = \"Anulowane\";\n"
"\"job-state.8\" = \"Przerwane\";\n"
"\"job-state.9\" = \"Zakończone\";\n"
"\"joining\" = \"dołączenie\";\n"
"\"media\" = \"Nośniki\";\n"
"\"media-col\" = \"Nośniki\";\n"
"\"media-size\" = \"Rozmiar nośnika\";\n"
"\"media-size-name\" = \"Rozmiar nośnika\";\n"
"\"media-source\" = \"Podajnik\";\n"
"\"media-source.alternate\" = \"Alternatywne\";\n"
"\"media-source.alternate-roll\" = \"Rolka zastępcza\";\n"
"\"media-source.auto\" = \"Automatyczne\";\n"
"\"media-source.bottom\" = \"Dół\";\n"
"\"media-source.by-pass-tray\" = \"Taca wielozadaniowa\";\n"
"\"media-source.center\" = \"Centrum\";\n"
"\"media-source.disc\" = \"Płyta\";\n"
"\"media-source.envelope\" = \"Koperta\";\n"
"\"media-source.hagaki\" = \"Hagaki\";\n"
"\"media-source.large-capacity\" = \"Duża pojemność\";\n"
"\"media-source.left\" = \"Lewo\";\n"
"\"media-source.main\" = \"Główne\";\n"
"\"media-source.main-roll\" = \"Główna rolka\";\n"
"\"media-source.manual\" = \"Ręczne\";\n"
"\"media-source.middle\" = \"Środek\";\n"
"\"media-source.photo\" = \"Zdjęcie\";\n"
"\"media-source.rear\" = \"Tył\";\n"
"\"media-source.right\" = \"Prawo\";\n"
"\"media-source.roll-1\" = \"Rolka 1\";\n"
"\"media-source.roll-10\" = \"Rolka 10\";\n"
"\"media-source.roll-2\" = \"Rolka 2\";\n"
"\"media-source.roll-3\" = \"Rolka 3\";\n"
"\"media-source.roll-4\" = \"Rolka 4\";\n"
"\"media-source.roll-5\" = \"Rolka 5\";\n"
"\"media-source.roll-6\" = \"Rolka 6\";\n"
"\"media-source.roll-7\" = \"Rolka 7\";\n"
"\"media-source.roll-8\" = \"Rolka 8\";\n"
"\"media-source.roll-9\" = \"Rolka 9\";\n"
"\"media-source.side\" = \"Bok\";\n"
"\"media-source.top\" = \"Góra\";\n"
"\"media-source.tray-1\" = \"Taca 1\";\n"
"\"media-source.tray-10\" = \"Taca 10\";\n"
"\"media-source.tray-11\" = \"Taca 11\";\n"
"\"media-source.tray-12\" = \"Taca 12\";\n"
"\"media-source.tray-13\" = \"Taca 13\";\n"
"\"media-source.tray-14\" = \"Taca 14\";\n"
"\"media-source.tray-15\" = \"Taca 15\";\n"
"\"media-source.tray-16\" = \"Taca 16\";\n"
"\"media-source.tray-17\" = \"Taca 17\";\n"
"\"media-source.tray-18\" = \"Taca 18\";\n"
"\"media-source.tray-19\" = \"Taca 19\";\n"
"\"media-source.tray-2\" = \"Taca 2\";\n"
"\"media-source.tray-20\" = \"Taca 20\";\n"
"\"media-source.tray-3\" = \"Taca 3\";\n"
"\"media-source.tray-4\" = \"Taca 4\";\n"
"\"media-source.tray-5\" = \"Taca 5\";\n"
"\"media-source.tray-6\" = \"Taca 6\";\n"
"\"media-source.tray-7\" = \"Taca 7\";\n"
"\"media-source.tray-8\" = \"Taca 8\";\n"
"\"media-source.tray-9\" = \"Taca 9\";\n"
"\"media-tracking\" = \"Śledzenie nośników\";\n"
"\"media-tracking.continuous\" = \"Ciągłe\";\n"
"\"media-tracking.gap\" = \"Dystans\";\n"
"\"media-tracking.mark\" = \"Znacznik\";\n"
"\"media-tracking.web\" = \"Internet\";\n"
"\"media-type\" = \"Typ nośników\";\n"
"\"media-type.aluminum\" = \"Aluminium\";\n"
"\"media-type.auto\" = \"Automatyczny\";\n"
"\"media-type.back-print-film\" = \"Folia nadrukowana z tyłu\";\n"
"\"media-type.cardboard\" = \"Karton\";\n"
"\"media-type.cardstock\" = \"Karta\";\n"
"\"media-type.cd\" = \"CD\";\n"
"\"media-type.continuous\" = \"Ciągły\";\n"
"\"media-type.continuous-long\" = \"Ciągły (długi)\";\n"
"\"media-type.continuous-short\" = \"Ciągły (krótki)\";\n"
"\"media-type.corrugated-board\" = \"Tektura falista\";\n"
"\"media-type.disc\" = \"Dysk optyczny\";\n"
"\"media-type.disc-glossy\" = \"Dysk optyczny błyszczący\";\n"
"\"media-type.disc-high-gloss\" = \"Dysk optyczny o wysokim połysku\";\n"
"\"media-type.disc-matte\" = \"Dysk optyczny matowy\";\n"
"\"media-type.disc-satin\" = \"Dysk optyczny satynowy\";\n"
"\"media-type.disc-semi-gloss\" = \"Dysk optyczny półbłyszczący\";\n"
"\"media-type.double-wall\" = \"Dwuścienny\";\n"
"\"media-type.dry-film\" = \"Folia sucha\";\n"
"\"media-type.dvd\" = \"DVD\";\n"
"\"media-type.embossing-foil\" = \"Folia tłoczona\";\n"
"\"media-type.end-board\" = \"Burta tylna\";\n"
"\"media-type.envelope\" = \"Koperta\";\n"
"\"media-type.envelope-archival\" = \"Koperta do archiwizacji\";\n"
"\"media-type.envelope-bond\" = \"Koperta bond\";\n"
"\"media-type.envelope-coated\" = \"Koperta powlekana\";\n"
"\"media-type.envelope-cotton\" = \"Koperta bawełniana\";\n"
"\"media-type.envelope-fine\" = \"Koperta drobna\";\n"
"\"media-type.envelope-heavyweight\" = \"Koperta o dużej gramaturze\";\n"
"\"media-type.envelope-inkjet\" = \"Koperta do druku atramentowego\";\n"
"\"media-type.envelope-lightweight\" = \"Koperta o lekkiej gramaturze\";\n"
"\"media-type.envelope-plain\" = \"Koperta zwykła\";\n"
"\"media-type.envelope-preprinted\" = \"Koperta z nadrukiem\";\n"
"\"media-type.envelope-window\" = \"Koperta z okienkiem\";\n"
"\"media-type.fabric\" = \"Tkanina\";\n"
"\"media-type.fabric-archival\" = \"Tkanina do archiwizacji\";\n"
"\"media-type.fabric-glossy\" = \"Tkanina błyszcząca\";\n"
"\"media-type.fabric-high-gloss\" = \"Tkanina o wysokim połysku\";\n"
"\"media-type.fabric-matte\" = \"Tkanina matowa\";\n"
"\"media-type.fabric-semi-gloss\" = \"Tkanina półbłyszcząca\";\n"
"\"media-type.fabric-waterproof\" = \"Tkanina wodoodporna\";\n"
"\"media-type.film\" = \"Film\";\n"
"\"media-type.flexo-base\" = \"Baza fleksograficzna\";\n"
"\"media-type.flexo-photo-polymer\" = \"Fotopolimer fleksograficzny\";\n"
"\"media-type.flute\" = \"Flet\";\n"
"\"media-type.foil\" = \"Folia\";\n"
"\"media-type.full-cut-tabs\" = \"Zakładki pełne\";\n"
"\"media-type.glass\" = \"Szkło\";\n"
"\"media-type.glass-colored\" = \"Szkło barwione\";\n"
"\"media-type.glass-opaque\" = \"Szkło nieprzezroczyste\";\n"
"\"media-type.glass-surfaced\" = \"Szkło wypolerowane\";\n"
"\"media-type.glass-textured\" = \"Szkło teksturowane\";\n"
"\"media-type.gravure-cylinder\" = \"Cylinder wklęsły\";\n"
"\"media-type.image-setter-paper\" = \"Papier do naświetlania\";\n"
"\"media-type.imaging-cylinder\" = \"Cylinder obrazujący\";\n"
"\"media-type.labels\" = \"Etykiety\";\n"
"\"media-type.labels-colored\" = \"Etykiety barwione\";\n"
"\"media-type.labels-glossy\" = \"Etykiety błyszczące\";\n"
"\"media-type.labels-high-gloss\" = \"Etykiety o wysokim połysku\";\n"
"\"media-type.labels-inkjet\" = \"Etykiety do druku atramentowego\";\n"
"\"media-type.labels-matte\" = \"Etykiety matowe\";\n"
"\"media-type.labels-permanent\" = \"Etykiety trwałe\";\n"
"\"media-type.labels-satin\" = \"Etykiety satynowe\";\n"
"\"media-type.labels-security\" = \"Etykiety zabezpieczające\";\n"
"\"media-type.labels-semi-gloss\" = \"Etykiety półbłyszczące\";\n"
"\"media-type.laminating-foil\" = \"Folia do laminowania\";\n"
"\"media-type.letterhead\" = \"Blankiet firmowy\";\n"
"\"media-type.metal\" = \"Metal\";\n"
"\"media-type.metal-glossy\" = \"Metal błyszczący\";\n"
"\"media-type.metal-high-gloss\" = \"Metal o wysokim połysku\";\n"
"\"media-type.metal-matte\" = \"Metal matowy\";\n"
"\"media-type.metal-satin\" = \"Metal satynowy\";\n"
"\"media-type.metal-semi-gloss\" = \"Metal półbłyszczący\";\n"
"\"media-type.mounting-tape\" = \"Taśma montażowa\";\n"
"\"media-type.multi-layer\" = \"Wielowarstwowy\";\n"
"\"media-type.multi-part-form\" = \"Formularz wieloczęściowy\";\n"
"\"media-type.other\" = \"Inny\";\n"
"\"media-type.paper\" = \"Papier\";\n"
"\"media-type.photographic\" = \"Papier fotograficzny\";\n"
"\"media-type.photographic-archival\" = \"Fotograficzna do archiwizacji\";\n"
"\"media-type.photographic-film\" = \"Film fotograficzny\";\n"
"\"media-type.photographic-glossy\" = \"Papier fotograficzny błyszczący\";\n"
"\"media-type.photographic-high-gloss\" = \"Papier fotograficzny o wysokim połysku\";\n"
"\"media-type.photographic-matte\" = \"Papier fotograficzny matowy\";\n"
"\"media-type.photographic-satin\" = \"Papier fotograficzny satynowy\";\n"
"\"media-type.photographic-semi-gloss\" = \"Papier fotograficzny półbłyszczący\";\n"
"\"media-type.plastic\" = \"Plastik\";\n"
"\"media-type.plastic-archival\" = \"Plastik do archiwizacji\";\n"
"\"media-type.plastic-colored\" = \"Plastik barwiony\";\n"
"\"media-type.plastic-glossy\" = \"Plastik błyszczący\";\n"
"\"media-type.plastic-high-gloss\" = \"Plastik o wysokim połysku\";\n"
"\"media-type.plastic-matte\" = \"Plastik matowy\";\n"
"\"media-type.plastic-satin\" = \"Plastik satynowy\";\n"
"\"media-type.plastic-semi-gloss\" = \"Plastik półbłyszczący\";\n"
"\"media-type.plate\" = \"Płyta offsetowa\";\n"
"\"media-type.polyester\" = \"Poliester\";\n"
"\"media-type.pre-cut-tabs\" = \"Zakładki wstępnie przycięte\";\n"
"\"media-type.roll\" = \"Rolka\";\n"
"\"media-type.screen\" = \"Ekran\";\n"
"\"media-type.screen-paged\" = \"Ekran stronicowany\";\n"
"\"media-type.self-adhesive\" = \"Samoprzylepny\";\n"
"\"media-type.self-adhesive-film\" = \"Folia samoprzylepna\";\n"
"\"media-type.shrink-foil\" = \"Folia termokurczliwa\";\n"
"\"media-type.single-face\" = \"Powierzchnia pojedyncza\";\n"
"\"media-type.single-wall\" = \"Jednościenny\";\n"
"\"media-type.sleeve\" = \"Koszulka\";\n"
"\"media-type.stationery\" = \"Materiały piśmienne\";\n"
"\"media-type.stationery-archival\" = \"Materiały piśmienne do archiwizacji\";\n"
"\"media-type.stationery-coated\" = \"Papier powlekany\";\n"
"\"media-type.stationery-cotton\" = \"Materiały piśmienne bawełniane\";\n"
"\"media-type.stationery-fine\" = \"Papier welinowy\";\n"
"\"media-type.stationery-heavyweight\" = \"Papier o dużej gramaturze\";\n"
"\"media-type.stationery-heavyweight-coated\" = \"Materiały piśmienne o dużej gramaturze, powlekane\";\n"
"\"media-type.stationery-inkjet\" = \"Papier biurowy do druku atramentowego\";\n"
"\"media-type.stationery-letterhead\" = \"Blankiet firmowy\";\n"
"\"media-type.stationery-lightweight\" = \"Papier o lekkiej gramaturze\";\n"
"\"media-type.stationery-preprinted\" = \"Papier wstępnie zadrukowany\";\n"
"\"media-type.stationery-prepunched\" = \"Papier dziurkowany\";\n"
"\"media-type.tab-stock\" = \"Papier z zakładkami\";\n"
"\"media-type.tractor\" = \"Traktor\";\n"
"\"media-type.transfer\" = \"Transferowy\";\n"
"\"media-type.transparency\" = \"Przezroczysty\";\n"
"\"media-type.triple-wall\" = \"Trójścienny\";\n"
"\"media-type.wet-film\" = \"Film wilgotny\";\n"
"\"media.choice_iso_a4_210x297mm_na_letter_8.5x11in\" = \"A4 lub US Letter\";\n"
"\"media.iso_2a0_1189x1682mm\" = \"2a0\";\n"
"\"media.iso_a0_841x1189mm\" = \"A0\";\n"
"\"media.iso_a0x3_1189x2523mm\" = \"A0x3\";\n"
"\"media.iso_a10_26x37mm\" = \"A10\";\n"
"\"media.iso_a1_594x841mm\" = \"A1\";\n"
"\"media.iso_a1x3_841x1783mm\" = \"A1x3\";\n"
"\"media.iso_a1x4_841x2378mm\" = \"A1x4\";\n"
"\"media.iso_a2_420x594mm\" = \"A2\";\n"
"\"media.iso_a2x3_594x1261mm\" = \"A2x3\";\n"
"\"media.iso_a2x4_594x1682mm\" = \"A2x4\";\n"
"\"media.iso_a2x5_594x2102mm\" = \"A2x5\";\n"
"\"media.iso_a3-extra_322x445mm\" = \"A3 (extra)\";\n"
"\"media.iso_a3_297x420mm\" = \"A3\";\n"
"\"media.iso_a3x3_420x891mm\" = \"A3x3\";\n"
"\"media.iso_a3x4_420x1189mm\" = \"A3x4\";\n"
"\"media.iso_a3x5_420x1486mm\" = \"A3x5\";\n"
"\"media.iso_a3x6_420x1783mm\" = \"A3x6\";\n"
"\"media.iso_a3x7_420x2080mm\" = \"A3x7\";\n"
"\"media.iso_a4-extra_235.5x322.3mm\" = \"A4 (extra)\";\n"
"\"media.iso_a4-tab_225x297mm\" = \"A4 (tab)\";\n"
"\"media.iso_a4_210x297mm\" = \"A4\";\n"
"\"media.iso_a4x3_297x630mm\" = \"A4x3\";\n"
"\"media.iso_a4x4_297x841mm\" = \"A4x4\";\n"
"\"media.iso_a4x5_297x1051mm\" = \"A4x5\";\n"
"\"media.iso_a4x6_297x1261mm\" = \"A4x6\";\n"
"\"media.iso_a4x7_297x1471mm\" = \"A4x7\";\n"
"\"media.iso_a4x8_297x1682mm\" = \"A4x8\";\n"
"\"media.iso_a4x9_297x1892mm\" = \"A4x9\";\n"
"\"media.iso_a5-extra_174x235mm\" = \"A5 (extra)\";\n"
"\"media.iso_a5_148x210mm\" = \"A5\";\n"
"\"media.iso_a6_105x148mm\" = \"A6\";\n"
"\"media.iso_a7_74x105mm\" = \"A7\";\n"
"\"media.iso_a8_52x74mm\" = \"A8\";\n"
"\"media.iso_a9_37x52mm\" = \"A9\";\n"
"\"media.iso_b0_1000x1414mm\" = \"B0\";\n"
"\"media.iso_b10_31x44mm\" = \"B10\";\n"
"\"media.iso_b1_707x1000mm\" = \"B1\";\n"
"\"media.iso_b2_500x707mm\" = \"B2\";\n"
"\"media.iso_b3_353x500mm\" = \"B3\";\n"
"\"media.iso_b4_250x353mm\" = \"B4\";\n"
"\"media.iso_b5-extra_201x276mm\" = \"B5 (extra)\";\n"
"\"media.iso_b5_176x250mm\" = \"B5 Koperta\";\n"
"\"media.iso_b6_125x176mm\" = \"B6\";\n"
"\"media.iso_b6c4_125x324mm\" = \"B6/C4 Koperta\";\n"
"\"media.iso_b7_88x125mm\" = \"B7\";\n"
"\"media.iso_b8_62x88mm\" = \"B8\";\n"
"\"media.iso_b9_44x62mm\" = \"B9\";\n"
"\"media.iso_c0_917x1297mm\" = \"C0 Koperta\";\n"
"\"media.iso_c10_28x40mm\" = \"C10 Koperta\";\n"
"\"media.iso_c1_648x917mm\" = \"C1 Koperta\";\n"
"\"media.iso_c2_458x648mm\" = \"C2 Koperta\";\n"
"\"media.iso_c3_324x458mm\" = \"C3 Koperta\";\n"
"\"media.iso_c4_229x324mm\" = \"C4 Koperta\";\n"
"\"media.iso_c5_162x229mm\" = \"C5 Koperta\";\n"
"\"media.iso_c6_114x162mm\" = \"C6 Koperta\";\n"
"\"media.iso_c6c5_114x229mm\" = \"C6/C5 Koperta\";\n"
"\"media.iso_c7_81x114mm\" = \"C7 Koperta\";\n"
"\"media.iso_c7c6_81x162mm\" = \"C7/C6 Koperta\";\n"
"\"media.iso_c8_57x81mm\" = \"C8 Koperta\";\n"
"\"media.iso_c9_40x57mm\" = \"C9 Koperta\";\n"
"\"media.iso_dl_110x220mm\" = \"DL Koperta\";\n"
"\"media.iso_ra0_860x1220mm\" = \"ISO RA0\";\n"
"\"media.iso_ra1_610x860mm\" = \"ISO RA1\";\n"
"\"media.iso_ra2_430x610mm\" = \"ISO RA2\";\n"
"\"media.iso_ra3_305x430mm\" = \"ISO RA3\";\n"
"\"media.iso_ra4_215x305mm\" = \"ISO RA4\";\n"
"\"media.iso_sra0_900x1280mm\" = \"ISO SRA0\";\n"
"\"media.iso_sra1_640x900mm\" = \"ISO SRA1\";\n"
"\"media.iso_sra2_450x640mm\" = \"ISO SRA2\";\n"
"\"media.iso_sra3_320x450mm\" = \"ISO SRA3\";\n"
"\"media.iso_sra4_225x320mm\" = \"ISO SRA4\";\n"
"\"media.jis_b0_1030x1456mm\" = \"JIS B0\";\n"
"\"media.jis_b10_32x45mm\" = \"JIS B10\";\n"
"\"media.jis_b1_728x1030mm\" = \"JIS B1\";\n"
"\"media.jis_b2_515x728mm\" = \"JIS B2\";\n"
"\"media.jis_b3_364x515mm\" = \"JIS B3\";\n"
"\"media.jis_b4_257x364mm\" = \"JIS B4\";\n"
"\"media.jis_b5_182x257mm\" = \"JIS B5\";\n"
"\"media.jis_b6_128x182mm\" = \"JIS B6\";\n"
"\"media.jis_b7_91x128mm\" = \"JIS B7\";\n"
"\"media.jis_b8_64x91mm\" = \"JIS B8\";\n"
"\"media.jis_b9_45x64mm\" = \"JIS B9\";\n"
"\"media.jis_exec_216x330mm\" = \"JIS Executive\";\n"
"\"media.jpn_chou2_111.1x146mm\" = \"Koperta Chou 2\";\n"
"\"media.jpn_chou3_120x235mm\" = \"Koperta Chou 3\";\n"
"\"media.jpn_chou40_90x225mm\" = \"Koperta Chou 40\";\n"
"\"media.jpn_chou4_90x205mm\" = \"Koperta Chou 4\";\n"
"\"media.jpn_hagaki_100x148mm\" = \"Hagaki\";\n"
"\"media.jpn_kahu_240x322.1mm\" = \"Koperta Kahu\";\n"
"\"media.jpn_kaku2_240x332mm\" = \"Koperta Kahu 2\";\n"
"\"media.jpn_oufuku_148x200mm\" = \"Pocztówka z odpowiedzią (Oufuku Reply Postcard)\";\n"
"\"media.jpn_you4_105x235mm\" = \"Koperta You 4\";\n"
"\"media.na_a2_4.375x5.75in\" = \"Koperta A2\";\n"
"\"media.na_c5_6.5x9.5in\" = \"Koperta C5\";\n"
"\"media.na_executive_7.25x10.5in\" = \"Executive\";\n"
"\"media.na_fanfold-eur_8.5x12in\" = \"Składanka europejska\";\n"
"\"media.na_fanfold-us_11x14.875in\" = \"Składanka amerykańska\";\n"
"\"media.na_foolscap_8.5x13in\" = \"Papier kancelaryjny\";\n"
"\"media.na_invoice_5.5x8.5in\" = \"Oświadczenie\";\n"
"\"media.na_legal-extra_9.5x15in\" = \"US Legal (Extra)\";\n"
"\"media.na_legal_8.5x14in\" = \"US Legal\";\n"
"\"media.na_letter-extra_9.5x12in\" = \"US Letter (Extra)\";\n"
"\"media.na_letter-plus_8.5x12.69in\" = \"US Letter (Plus)\";\n"
"\"media.na_letter_8.5x11in\" = \"US Letter\";\n"
"\"media.na_monarch_3.875x7.5in\" = \"Koperta Monarch\";\n"
"\"media.na_number-10_4.125x9.5in\" = \"Koperta #10\";\n"
"\"media.na_number-11_4.5x10.375in\" = \"Koperta #11\";\n"
"\"media.na_number-12_4.75x11in\" = \"Koperta #12\";\n"
"\"media.na_number-14_5x11.5in\" = \"Koperta #14\";\n"
"\"media.na_number-9_3.875x8.875in\" = \"Koperta #9\";\n"
"\"media.na_personal_3.625x6.5in\" = \"Koperta Personal\";\n"
"\"media.na_quarto_8.5x10.83in\" = \"Quarto\";\n"
"\"media.om_folio-sp_215x315mm\" = \"Folio\";\n"
"\"media.om_folio_210x330mm\" = \"Folio (Special)\";\n"
"\"media.om_invite_220x220mm\" = \"Koperta zaproszeniowa\";\n"
"\"media.om_italian_110x230mm\" = \"Koperta włoska\";\n"
"\"media.om_juuro-ku-kai_198x275mm\" = \"198 x 275 mm\";\n"
"\"media.om_large-photo_200x300\" = \"200 x 300 mm\";\n"
"\"media.om_medium-photo_130x180mm\" = \"130 x 180 mm\";\n"
"\"media.om_pa-kai_267x389mm\" = \"267 x 389 mm\";\n"
"\"media.om_postfix_114x229mm\" = \"Koperta Postfix\";\n"
"\"media.prc_10_324x458mm\" = \"Koperta chińska #10\";\n"
"\"media.prc_16k_146x215mm\" = \"Chińska 16k\";\n"
"\"media.prc_1_102x165mm\" = \"Koperta chińska #1\";\n"
"\"media.prc_2_102x176mm\" = \"Koperta chińska #2\";\n"
"\"media.prc_32k_97x151mm\" = \"Chińska 32k\";\n"
"\"media.prc_3_125x176mm\" = \"Koperta chińska #3\";\n"
"\"media.prc_4_110x208mm\" = \"Koperta chińska #4\";\n"
"\"media.prc_5_110x220mm\" = \"Koperta chińska #5\";\n"
"\"media.prc_6_120x320mm\" = \"Koperta chińska #6\";\n"
"\"media.prc_7_160x230mm\" = \"Koperta chińska #7\";\n"
"\"media.prc_8_120x309mm\" = \"Koperta chińska #8\";\n"
"\"media.roc_16k_7.75x10.75in\" = \"ROC 16k\";\n"
"\"media.roc_8k_10.75x15.5in\" = \"ROC 8k\";\n"
"\"not configured\" = \"nie skonfigurowano\";\n"
"\"not visible\" = \"niewidoczne\";\n"
"\"off\" = \"wyłączone\";\n"
"\"on\" = \"włączone\";\n"
"\"orientation-requested\" = \"Orientacja\";\n"
"\"orientation-requested.3\" = \"Pionowa\";\n"
"\"orientation-requested.4\" = \"Pozioma\";\n"
"\"orientation-requested.5\" = \"Pozioma (obrócona)\";\n"
"\"orientation-requested.6\" = \"Pionowa (obrócona)\";\n"
"\"orientation-requested.7\" = \"Brak\";\n"
"\"output-bin\" = \"Odbiornik\";\n"
"\"output-bin.auto\" = \"Automatyczny\";\n"
"\"output-bin.bottom\" = \"Dół\";\n"
"\"output-bin.center\" = \"Centrum\";\n"
"\"output-bin.face-down\" = \"Do dołu\";\n"
"\"output-bin.face-up\" = \"Do góry\";\n"
"\"output-bin.large-capacity\" = \"Duża pojemność\";\n"
"\"output-bin.left\" = \"Lewo\";\n"
"\"output-bin.mailbox-1\" = \"Skrzynka pocztowa 1\";\n"
"\"output-bin.mailbox-10\" = \"Skrzynka pocztowa 10\";\n"
"\"output-bin.mailbox-2\" = \"Skrzynka pocztowa 2\";\n"
"\"output-bin.mailbox-3\" = \"Skrzynka pocztowa 3\";\n"
"\"output-bin.mailbox-4\" = \"Skrzynka pocztowa 4\";\n"
"\"output-bin.mailbox-5\" = \"Skrzynka pocztowa 5\";\n"
"\"output-bin.mailbox-6\" = \"Skrzynka pocztowa 6\";\n"
"\"output-bin.mailbox-7\" = \"Skrzynka pocztowa 7\";\n"
"\"output-bin.mailbox-8\" = \"Skrzynka pocztowa 8\";\n"
"\"output-bin.mailbox-9\" = \"Skrzynka pocztowa 9\";\n"
"\"output-bin.middle\" = \"Środek\";\n"
"\"output-bin.my-mailbox\" = \"Moja skrzynka pocztowa\";\n"
"\"output-bin.rear\" = \"Tył\";\n"
"\"output-bin.right\" = \"Prawo\";\n"
"\"output-bin.side\" = \"Bok\";\n"
"\"output-bin.stacker-1\" = \"Zszywacz 1\";\n"
"\"output-bin.stacker-10\" = \"Zszywacz 10\";\n"
"\"output-bin.stacker-2\" = \"Zszywacz 2\";\n"
"\"output-bin.stacker-3\" = \"Zszywacz 3\";\n"
"\"output-bin.stacker-4\" = \"Zszywacz 4\";\n"
"\"output-bin.stacker-5\" = \"Zszywacz 5\";\n"
"\"output-bin.stacker-6\" = \"Zszywacz 6\";\n"
"\"output-bin.stacker-7\" = \"Zszywacz 7\";\n"
"\"output-bin.stacker-8\" = \"Zszywacz 8\";\n"
"\"output-bin.stacker-9\" = \"Zszywacz 9\";\n"
"\"output-bin.top\" = \"Góra\";\n"
"\"output-bin.tray-1\" = \"Taca 1\";\n"
"\"output-bin.tray-10\" = \"Taca 10\";\n"
"\"output-bin.tray-2\" = \"Taca 2\";\n"
"\"output-bin.tray-3\" = \"Taca 3\";\n"
"\"output-bin.tray-4\" = \"Taca 4\";\n"
"\"output-bin.tray-5\" = \"Taca 5\";\n"
"\"output-bin.tray-6\" = \"Taca 6\";\n"
"\"output-bin.tray-7\" = \"Taca 7\";\n"
"\"output-bin.tray-8\" = \"Taca 8\";\n"
"\"output-bin.tray-9\" = \"Taca 9\";\n"
"\"print-color-mode\" = \"Tryb drukowania\";\n"
"\"print-color-mode.auto\" = \"Automatyczny\";\n"
"\"print-color-mode.auto-monochrome\" = \"Auto. monochromia\";\n"
"\"print-color-mode.bi-level\" = \"Tekst\";\n"
"\"print-color-mode.color\" = \"Kolor\";\n"
"\"print-color-mode.highlight\" = \"Wyróżnienie\";\n"
"\"print-color-mode.monochrome\" = \"Monochromia\";\n"
"\"print-color-mode.process-bi-level\" = \"Przetwarzanie tekstu\";\n"
"\"print-color-mode.process-monochrome\" = \"Przetwarzanie monochromi\";\n"
"\"print-content-optimize\" = \"Optymalizuj pod kątem\";\n"
"\"print-content-optimize.auto\" = \"Automatycznie\";\n"
"\"print-content-optimize.graphic\" = \"Grafiki\";\n"
"\"print-content-optimize.photo\" = \"Zdjęć\";\n"
"\"print-content-optimize.text\" = \"Tekstu\";\n"
"\"print-content-optimize.text-and-graphic\" = \"Tekstu i grafiki\";\n"
"\"print-darkness\" = \"Ciemność wydruku\";\n"
"\"print-quality\" = \"Jakość wydruku\";\n"
"\"print-quality.3\" = \"Szkic\";\n"
"\"print-quality.4\" = \"Normalna\";\n"
"\"print-quality.5\" = \"Najlepsza\";\n"
"\"print-scaling\" = \"Skalowanie\";\n"
"\"print-scaling.auto\" = \"Automatyczne\";\n"
"\"print-scaling.auto-fit\" = \"Automatyczne dopasowanie\";\n"
"\"print-scaling.fill\" = \"Wypełnianie\";\n"
"\"print-scaling.fit\" = \"Dopasowanie\";\n"
"\"print-scaling.none\" = \"Brak\";\n"
"\"print-speed\" = \"Szybkość drukowania\";\n"
"\"printer-resolution\" = \"Rozdzielczość\";\n"
"\"printer-state-reasons.cover-open\" = \"Pokrywa otwarta.\";\n"
"\"printer-state-reasons.door-open\" = \"Drzwi otwarte.\";\n"
"\"printer-state-reasons.identify-printer-requested\" = \"Zidentyfikuj drukarkę.\";\n"
"\"printer-state-reasons.input-tray-missing\" = \"Brak zasobnika papieru.\";\n"
"\"printer-state-reasons.marker-supply-empty\" = \"Brak atramentu.\";\n"
"\"printer-state-reasons.marker-supply-low\" = \"Niski poziom atramentu.\";\n"
"\"printer-state-reasons.marker-waste-almost-full\" = \"Kosz na śmieci prawie pełny.\";\n"
"\"printer-state-reasons.marker-waste-full\" = \"Kosz na śmieci pełny.\";\n"
"\"printer-state-reasons.media-empty\" = \"Brak papieru.\";\n"
"\"printer-state-reasons.media-jam\" = \"Zacięcie papieru.\";\n"
"\"printer-state-reasons.media-low\" = \"Wkrótce wymień papier.\";\n"
"\"printer-state-reasons.media-needed\" = \"Włóż papier.\";\n"
"\"printer-state-reasons.none\" = \"Gotowa.\";\n"
"\"printer-state-reasons.offline\" = \"Offline.\";\n"
"\"printer-state-reasons.other\" = \"Zobacz drukarkę.\";\n"
"\"printer-state-reasons.spool-area-full\" = \"Drukarka zajęta.\";\n"
"\"printer-state-reasons.toner-empty\" = \"Brak tonera.\";\n"
"\"printer-state-reasons.toner-low\" = \"Niski poziom tonera.\";\n"
"\"printer-state.3\" = \"Bezczynna\";\n"
"\"printer-state.4\" = \"Przetwarzanie\";\n"
"\"printer-state.5\" = \"Zatrzymana\";\n"
"\"sides\" = \"Drukowanie dwustronne\";\n"
"\"sides.one-sided\" = \"Wyłączone\";\n"
"\"sides.two-sided-long-edge\" = \"Wyłączone (pionowo)\";\n"
"\"sides.two-sided-short-edge\" = \"Wyłączone (poziomo)\";\n"
"\"unable to join\" = \"nie można dołączyć\";\n"
"\"yesterday at %02d:%02d:%02d\" = \"wczoraj o %02d:%02d:%02d\";\n"
"\"Åland Islands\" = \"Wyspy Alandzkie\";\n";
